# Edit and set server name and version
test_server_name = '<put server name here>'
test_server_version = '201X'

# Edit and direct to your test folders on your server
test_folder = r'\Tests'
test_mkfolder = r'\Tests\New Folder'
test_newfoldername = 'Renamed folder'
test_renamedfolder = r'\Tests\Renamed folder'

# Edit and direct to your test models on your server
test_file = r'\Tests\TestModel.rvt'
test_cpyfile = r'\Tests\TestModelCopy.rvt'
test_mvfile = r'\Tests\TestModelMove.rvt'
test_mhistory = r'\Tests\TestModel.rvt'
