#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['rpws']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.6']

setup(name='rpws',
      version='1.0.0',
      description='python wrapper for Autodesk Revit Server',
      author='Ehsan Iran-Nejad',
      author_email='eirannejad@gmail.com',
      url='https://github.com/eirannejad/rpws',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      python_requires='>=2.7',
     )
